// Warcolours
// 75.7 Long
// 23.4 Diameter
// 49 Base

// Vallejo
// 77 Long
// 24.5 Diameter
// 48 Base

// Reaper
// 74.5 Long
// 24.9 Diameter
// 42 Base

pots_x = 10;
pots_y = 4;
padding = 5;
pot_base = 25;
pot_top = 20;
pot_extra_spacing = 1;
tabs = 5;

middle_gap = 32;
back_gap = 33;

module front(x=4, y=3, spacing=10, hole=33, tabs=3, tab=3.175) {
    difference() {
        face(x, y, spacing, hole, tabs, tab);
        for (i = [1:x]) {
            for (j = [1:y]) {
                translate([(spacing+hole)*i-hole/2+tab,(spacing+hole)*j-hole/2+tab]) circle(hole/2);
            }
        }
    }
}

module middle(x=4, y=3, spacing=10, front_hole=33, hole=25, tabs=3, tab=3.175) {
    difference() {
        face(x, y, spacing, front_hole, tabs, tab);
        for (i = [1:x]) {
            for (j = [1:y]) {
                translate([(spacing+front_hole)*i-front_hole/2+tab,(spacing+front_hole)*j-front_hole/2+tab]) circle(hole/2);
            }
        }
    }
}

module face(x=4, y=3, spacing=10, hole=33, tabs=3, tab=3.175) {
    x_length = x * hole + spacing * (x+1) + tab*2;
    y_length = y * hole + spacing * (y+1) + tab*2;
    difference() {
        union() {
            translate([0,tab]) square([x_length,y_length-tab*2]);
            for (i = [0:tabs-1]) {
                hole = (x_length - spacing * 4) / (tabs - 1);
                translate([hole * i + spacing * 2,0]) translate([-10/2,0]) square([10,tab]);
                translate([(hole * i + spacing * 2), y_length-tab]) translate([-10/2,0]) square([10,tab]);
            }
        }
        translate([-1,tab-1]) square([tab+1, 21]);
        translate([-1,y_length-tab-20]) square([tab+1, 21]);
        translate([x_length-tab,tab-1]) square([tab+1, 21]);
        translate([x_length-tab,y_length-tab-20]) square([tab+1, 21]);
    }
}

module side(x=4, y=3, middle_gap=30, back_gap=30, spacing=10, hole=33, tabs=3, tab=3.175) {
    x_length = x * hole + spacing * (x+1) + tab*2;
    y_length = middle_gap + back_gap;

    difference() {
        translate([0, 0]) square([x_length,y_length]);
        for (i = [0:tabs-1]) {
            hole = (x_length - spacing * 4) / (tabs - 1);
            translate([hole * i + spacing * 2,-1]) translate([-10/2,0]) square([10,tab+1]);
            translate([hole * i + spacing * 2,middle_gap]) translate([-10/2,0]) square([10,tab]);
            translate([hole * i + spacing * 2,y_length-tab]) translate([-10/2,0]) square([10,tab+1]);
            if(i != tabs-1) {
                translate([hole*i+spacing+10,spacing]) rounded_square(hole-10,middle_gap-spacing*2+tab,2);
                translate([hole*i+spacing+10,spacing+middle_gap]) rounded_square(hole-10,back_gap-spacing*2,2);
            }
        }
        translate([-1,middle_gap/2-5]) square([tab+1,10]);
        translate([x_length-tab,middle_gap/2-5]) square([tab+1,10]);
        translate([-1,middle_gap+back_gap/2-5]) square([tab+1,10]);
        translate([x_length-tab,middle_gap+back_gap/2-5]) square([tab+1,10]);
    }

/*    translate([0, y_length-tab*3]) square([x*hole+spacing*(x+1),tab*2]);
    translate([0, tab]) square([spacing*2,y_length-tab*2]);
    translate([x_length-spacing*2, tab]) square([spacing*2,y_length-tab*2]);*/
}

module side2(middle_gap=30, back_gap=30, tab=3.175) {
    y_length = middle_gap + back_gap;
    echo(y_length);
    difference() {
        square([20,y_length]);
        translate([5,y_length-tab]) square([10,tab+1]);
    }
    translate([19,middle_gap/2-5]) square([tab+1,10]);
    translate([19,middle_gap+back_gap/2-5]) square([tab+1,10]);
}

module back(x=4, y=3, spacing=10, hole=33, tabs=3, tab=3.175) {
    x_length = x * hole + spacing * (x+1) + tab*2;
    difference() {
        translate([tab,0]) square([x_length-tab*2, 20]);
        for(i = [1:floor(x_length/20)-1]) {
            translate([i*20,10]) circle(1.5,$fn=20);
        }
    }
    translate([0,5]) square([tab+1,10]);
    translate([x_length-tab-1,5]) square([tab+1,10]);
    for (i = [0:tabs-1]) {
        hole = (x_length - spacing * 4) / (tabs - 1);
        translate([hole * i + spacing * 2,19]) translate([-10/2,0]) square([10,tab+1]);
    }
}

module rounded_square(x, y, radius) {
    hull() {
        translate([radius, radius]) circle(radius,$fn=20);
        translate([x-radius, radius]) circle(radius,$fn=20);
        translate([radius, y-radius]) circle(radius,$fn=20);
        translate([x-radius, y-radius]) circle(radius,$fn=20);
    }
}

//front(pots_x, pots_y, padding, pot_base+pot_extra_spacing, tabs);
//middle(pots_x, pots_y, padding, pot_base+pot_extra_spacing, pot_top+pot_extra_spacing, tabs);
//side(pots_x, pots_y, middle_gap, back_gap, padding, pot_base+pot_extra_spacing, tabs);
side2(middle_gap, back_gap);
//back(pots_x, pots_y, padding, pot_base+pot_extra_spacing, tabs);
